@@ -24,14 +24,16 @@ class LocalShell(object):
         subprocess.Popen(**self._subprocess_args(*args, **kwargs))
         
     def run(self, *args, **kwargs):
+        allow_error = kwargs.pop("allow_error", False)
         process = subprocess.Popen(**self._subprocess_args(*args, **kwargs))
         stdout, stderr = process.communicate()
         return_code = process.poll()
-        if return_code == 0:
-            return ExecutionResult(stdout)
-        else:
-            raise spur.results.RunProcessError(return_code, stdout, stderr)
-        
+        return spur.results.result(
+            return_code,
+            stdout,
+            stderr,
+            allow_error=allow_error
+        )
         
     def temporary_dir(self):
         return create_temporary_dir()
@@ -54,8 +56,3 @@ class LocalShell(object):
         if new_process_group:
             kwargs["preexec_fn"] = os.setpgrp
         return kwargs
-
-class ExecutionResult(object):
-    def __init__(self, output):
-        self.output = output
-
