@@ -22,6 +22,7 @@ class SshShell(object):
         self._client = None
 
     def run(self, *args, **kwargs):
+        allow_error = kwargs.pop("allow_error", False)
         command_in_cwd = self._generate_run_command(*args, **kwargs)
         
         with self._connect_ssh() as client:
@@ -37,14 +38,13 @@ class SshShell(object):
             return_code = int(output[-1])
             # Strip the extra newline and line containing the return code
             output_as_str = "".join(output[:-1])[:-1]
-            if return_code == 0:
-                return ExecutionResult(output_as_str)
-            else:
-                raise spur.results.RunProcessError(
-                    return_code=return_code,
-                    output=output_as_str,
-                    stderr_output="".join(stderr_output)
-                )
+            stderr_output_as_str = "".join(stderr_output)
+            return spur.results.result(
+                return_code,
+                output_as_str,
+                stderr_output_as_str,
+                allow_error=allow_error
+            )
     
     def spawn(self, *args, **kwargs):
         command_in_cwd = self._generate_run_command(*args, **kwargs)
@@ -150,10 +150,5 @@ class SftpFile(object):
         self.close()
         
 
-class ExecutionResult(object):
-    def __init__(self, output):
-        self.output = output
-        
-
 def escape_sh(value):
     return "'" + value.replace("'", "'\\''") + "'"
